package lttc.cn.centeen.service.Impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import lttc.cn.centeen.entity.Review;
import lttc.cn.centeen.mapper.AdviceMapper;
import lttc.cn.centeen.service.ReviewService;
import lttc.cn.centeen.utils.CommonUtils;
import lttc.cn.centeen.utils.MinioUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;
import java.util.Comparator;
import java.util.List;
import java.util.Objects;

/**
 * 功能描述
 * @author: scott
 * @date: 2024年07月19日 PM 3:10
 */
@Service
public class ReviewServiceImpl implements ReviewService {

    @Autowired
    private AdviceMapper adviceMapper;

    // 添加評論
    @Override
    public void addReview(List<MultipartFile> images, String advice) {
        StringBuilder sb = new StringBuilder();
        // 文件上传 minio 文件服务器
        if (images !=null){
            images.forEach(image -> {
                System.out.println("image："+image.getOriginalFilename());
                String orgName = image.getOriginalFilename();
                assert orgName != null;
                orgName = CommonUtils.getFileName(orgName);
                String fileUrl = null;
                try {
                    fileUrl = MinioUtil.upload(image,null);
                    System.out.println("fileUrl："+fileUrl);
                    int lastSlashIndex = fileUrl.lastIndexOf('/');
                    String fileName = fileUrl.substring(lastSlashIndex + 1);
                    if (!fileName.isEmpty()){
                        sb.append(fileName).append(",");
                    }
                } catch (Exception e) {
                    throw new RuntimeException(e);
                }
            });
        }

        String result = sb.toString();
        // 去除最后一个逗号
        result = result.replaceAll(",\\s*$", "");
        Review review = new Review();
        // 获取当前时间的毫秒级时间戳（id）
        String timestamp = String.valueOf(System.currentTimeMillis());
        review.setId(timestamp);
        review.setAdvice(advice);
        review.setImageInfoList(result);
        int i = adviceMapper.insert(review);
    }

    // 查询意见数据
    @Override
    public List<Review> queryReview() {
        QueryWrapper<Review> queryWrapper = new QueryWrapper<>();

        List<Review> reviews = adviceMapper.selectList(queryWrapper);

        // 使用stream API进行排序
        return reviews.stream()
                .sorted(Comparator.comparing(Review::getCreateTime).reversed())
                .toList();
    }

    // 删除意见数据
    @Override
    public void deleteAdviceInfoById(String id) {
        Review review = adviceMapper.selectById(id);
        String[] objectNameArray = review.getImageInfoList().split(",");
        // 删除文件服务器上的图片
        if (!Objects.equals(objectNameArray[0], "")){
            for (String objectName : objectNameArray) {
                MinioUtil.removeObject("canttenadvice",objectName);
            }
        }
        adviceMapper.deleteById(id);
    }
}
